@@ -27,11 +27,11 @@
 **
 ****************************************************************************/
 #include <QtTest/QtTest>
-#include <private/xydomain_p.h>
-#include <private/qabstractaxis_p.h>
+#include <QtCharts/private/xydomain_p.h>
+#include <QtCharts/private/qabstractaxis_p.h>
 #include <tst_definitions.h>
 
-QT_CHARTS_USE_NAMESPACE
+QT_USE_NAMESPACE
 
 Q_DECLARE_METATYPE(XYDomain*)
 Q_DECLARE_METATYPE(QSizeF)
